@@ -4,15 +4,14 @@ from .dist import init_dist, get_dist_info, master_only
 from .misc import (concat_list, convert_list, convert_list_str,
                    convert_list_int, convert_list_float, iter_cast, slice_list,
                    concat_list, check_prerequisites, deprecated_api_warning,
-                   is_seq_of, is_list_of, is_tuple_of, multi_apply)
+                   is_seq_of, is_list_of, is_tuple_of, multi_apply,
+                   is_multiple, is_power2)
 
 from .comm import (get_world_size, get_rank, get_local_rank, get_local_size,
                    is_main_process, synchronize, gather, all_gather,
                    shared_random_seed, reduce_dict)
 
-from .env import set_random_seed
-
-from .collect_env import collect_env_info
+from .env import set_random_seed, collect_env_info
 
 from .launch import launch
 
